.. _synoptics:

==========
Synoptics
==========

Synoptic widgets provide a graphical interface to control equipment. They may
display some graphics elements (realistic representations or schematic ones)
some of which may allow interactions (such as accept mouse clicks) or provide
updated values and changing colors.

.. figure:: /_static/synoptic01.png
  :align: center
  
  Example of a synoptic representing a beam line. Some active elements are
  marked with red squares and one has been selected which is shown by a blue
  ellipse.